import { StartFormation } from "./danceCommon.js";
import { LibFigureDance } from "./libfigureMapper.js";

export interface ContraDBDance {
  id: number,
  title: string,
  choreographer_name: string,
  start_type: StartFormation,
  preamble: string,
  figures: LibFigureDance,
  notes: string,
  hook: string,
}

// All of Isaac Banner's dances currently listed on ContraDB.
// Not intended to be an exhaustive collection of all contra dances, just enough variety to test the interpreter.
export const dances: ContraDBDance[] = [
  { "title": "Analemma", "choreographer_name": "Isaac Banner", "start_type": "Becket ccw", "preamble": "", "figures": [{ "parameter_values": ["ladles", true, "partners", 8], "move": "revolving door" }, { "parameter_values": ["neighbors", "none", 8], "move": "swing" }, { "parameter_values": ["gentlespoons", "", false, "half", "across", false, false, false, false, 8], "move": "hey" }, { "parameter_values": ["gentlespoons", false, "across", 8], "move": "chain" }, { "parameter_values": [true, 270, 6], "move": "circle" }, { "parameter_values": ["along", true, 2], "move": "pass through", "progression": 1 }, { "parameter_values": ["ladles", false, 360, 180, 8], "move": "allemande orbit" }, { "parameter_values": ["partners", "meltdown", 16], "move": "swing" }], "notes": "", "hook": "Larks chain, smooth orbit progression", "id": 1879 },
  { "title": "Another Smooth Bluesy Dance", "choreographer_name": "Isaac Banner", "start_type": "improper", "preamble": "", "figures": [{ "parameter_values": [false, 360, 8], "move": "circle" }, { "parameter_values": ["ladles", "", false, "half", "across", false, false, false, false, 8], "move": "hey" }, { "parameter_values": ["neighbors", "meltdown", 16], "move": "swing" }, { "parameter_values": ["gentlespoons", "", false, "half", "across", false, true, false, false, 8], "move": "hey" }, { "parameter_values": ["partners", "none", 8], "move": "swing" }, { "parameter_values": [true, 270, 8], "move": "circle" }, { "parameter_values": [0.5, "gentlespoons", "partners", true, 8], "move": "poussette", "progression": 1 }], "notes": "If you don't want to or don't have time to teach the half poussette, a zig zag works just fine as well to simplify the progression.", "hook": "Smooth bluesy dance", "id": 1318 },
  { "title": "Back to Back", "choreographer_name": "Isaac Banner", "start_type": "improper", "preamble": "", "figures": [{ "parameter_values": ["neighbors", "balance", 16], "move": "swing" }, { "parameter_values": ["neighbors", "across", false, 8], "move": "promenade" }, { "parameter_values": [true, 8], "move": "petronella" }, { "parameter_values": ["partners", "balance", 16], "move": "swing" }, { "parameter_values": [true, 8], "move": "petronella" }, { "parameter_values": [4], "move": "balance the ring" }, { "parameter_values": ["partners", 4], "move": "California twirl", "progression": 1 }], "notes": "Variation on Back to Front by Luke Donforth - swaps the robins allemande for a more symmetrical petronella to follow up on the truncated double petronella in the A1 - on Luke's website he mentions - \"I often think of Rory O’More and Petronella in happening in twos, but the following two dances use them in singletons to transition into something else.\" It seemed appropriate to double up on single petronellas.\n\nRotated to de-becketize, which also brings it pretty close to Brain Dead Balance **also** by Luke Donforth, who based Back to Front on A-1 Reel by Chris Weiler **and** clearly had a similar idea because he also wrote Double Balanced Brain which is a more symmetrical version of either dance than this one (but without a petronella left, the *coward*).......dances aren't really *\"written\"* or *\"original\"* - the dances don't need us to write them, they've always existed.", "hook": "Double petronellas, existential crises", "id": 2052 },
  { "title": "Bear Country", "choreographer_name": "Isaac Banner", "start_type": "Becket", "preamble": "", "figures": [{ "parameter_values": ["ladles", true, 540, 8], "move": "allemande" }, { "parameter_values": ["neighbors", "none", 8], "move": "swing" }, { "parameter_values": ["ladles", true, "across", 8], "move": "chain" }, { "parameter_values": [false, 360, "hands across", 8], "move": "star", "note": "" }, { "parameter_values": ["gentlespoons", false, false, 2], "move": "pull by dancers", "note": "(robins drop out)" }, { "parameter_values": ["neighbors", "", true, "partners%%2", "across", false, false, false, false, 14], "move": "hey" }, { "parameter_values": ["partners", "meltdown", 14], "move": "swing" }, { "parameter_values": [true, 2], "move": "slide along set", "progression": 1 }], "notes": "", "hook": "", "id": 895 },
  { "title": "Binary Stars", "choreographer_name": "Isaac Banner", "start_type": "improper", "preamble": "Starts in short waves, right hands to neighbors", "figures": [{ "parameter_values": ["everyone", true, false, 8], "move": "Rory O'More", "note": ", larks keep sliding past each other to catch left hands" }, { "parameter_values": [false, 360, "hands across", 8], "move": "star", "note": ", robins falling in behind partners" }, { "parameter_values": ["everyone", 4], "move": "balance", "note": "the star" }, { "parameter_values": ["ladles", false, true, 4], "move": "Rory O'More", "note": ", larks turn over right shoulders" }, { "parameter_values": [true, 360, "hands across", 8], "move": "star", "progression": 1 }, { "parameter_values": ["gentlespoons", false, 270, 6], "move": "allemande", "note": "with next lark" }, { "parameter_values": ["partners", "none", 10], "move": "swing" }, { "parameter_values": [true, 270, 8], "move": "circle" }, { "parameter_values": ["neighbors", true, 450, 8], "move": "do si do", "note": "to short waves" }], "notes": "Inspired by Catch a Falling Star, by Melanie Axel-Lute", "hook": "Stars balance with Rory inversion", "id": 1973 },
  { "title": "Birds from Urbana", "choreographer_name": "Isaac Banner", "start_type": "Becket", "preamble": "", "figures": [{ "parameter_values": [true, 270, 8], "move": "circle" }, { "parameter_values": ["partners", true, "allemande", 6], "move": "zig zag", "progression": 1 }, { "parameter_values": ["gentlespoons", false, 180, 2], "move": "allemande" }, { "parameter_values": ["neighbors", "meltdown", 16], "move": "swing" }, { "parameter_values": ["gentlespoons", 360, 8], "move": "mad robin" }, { "parameter_values": [true, 270, 8], "move": "circle" }, { "parameter_values": ["partners", "meltdown", 16], "move": "swing" }], "notes": "", "hook": "Bluesy zig zag", "id": 1289 },
  { "title": "Blue and Green Candles", "choreographer_name": "Isaac Banner", "start_type": "Becket", "preamble": "", "figures": [{ "parameter_values": ["ladles", false, true, 2], "move": "pull by dancers" }, { "parameter_values": ["neighbors", false, 270, 6], "move": "allemande", "progression": 1 }, { "parameter_values": ["ladles", true, true, 8], "move": "box circulate" }, { "parameter_values": ["gentlespoons", true, true, 8], "move": "box circulate" }, { "parameter_values": ["neighbors", "none", 8], "move": "swing" }, { "parameter_values": [true, 8], "move": "long lines" }, { "parameter_values": ["gentlespoons", 360, 8], "move": "mad robin" }, { "parameter_values": ["gentlespoons", "", false, "half", "across", false, true, false, false, 8], "move": "hey" }, { "parameter_values": ["partners", "none", 8], "move": "swing" }], "notes": "Written for the marriage of Margaret and Aaron.", "hook": "Box Circulates + richochet-hey-to-swing", "id": 1425 },
  { "title": "Bobbin' Robin", "choreographer_name": "Isaac Banner", "start_type": "Becket", "preamble": "", "figures": [{ "parameter_values": [true, 270, 6], "move": "circle" }, { "parameter_values": ["along", true, 2], "move": "pass through", "progression": 1 }, { "parameter_values": ["next neighbors", true, true, 8], "move": "box the gnat" }, { "parameter_values": [true, 360, "", 8], "move": "star" }, { "parameter_values": ["gentlespoons", 360, 8], "move": "mad robin" }, { "parameter_values": ["gentlespoons", "", false, "half", "across", false, false, false, false, 8], "move": "hey" }, { "parameter_values": ["gentlespoons", 360, 8], "move": "mad robin" }, { "parameter_values": ["gentlespoons", "", false, "half", "across", false, true, false, false, 8], "move": "hey", "note": "" }, { "parameter_values": ["partners", "none", 8], "move": "swing" }], "notes": "", "hook": "Double mad robin, ricochet hey to swing", "id": 335 },
  { "title": "Coming Home from Alaska", "choreographer_name": "Isaac Banner", "start_type": "Becket", "preamble": "", "figures": [{ "parameter_values": ["ladles", true, "across", 8], "move": "chain" }, { "parameter_values": [false, 360, 8], "move": "circle", "note": "" }, { "parameter_values": ["everyone", "", 0], "move": "turn alone", "progression": 1 }, { "parameter_values": [true, 180, 4], "move": "circle" }, { "parameter_values": ["neighbors", "none", 12], "move": "swing" }, { "parameter_values": ["gentlespoons", "", true, "full", "across", false, false, true, false, 16], "move": "hey" }, { "parameter_values": ["partners", "meltdown", 16], "move": "swing" }], "notes": "", "hook": "", "id": 2095 },
  { "title": "Creme Fraiche", "choreographer_name": "Isaac Banner", "start_type": "improper", "preamble": "Starts with the ones below", "figures": [{ "parameter_values": [true, 8], "move": "petronella" }, { "parameter_values": [4], "move": "balance the ring" }, { "parameter_values": ["gentlespoons", "partners", false, 4], "move": "roll away" }, { "parameter_values": ["gentlespoons", "", false, "full", "across", false, false, false, false, 16], "move": "hey" }, { "parameter_values": ["partners", "balance", 16], "move": "swing" }, { "parameter_values": ["left diagonal", 8], "move": "right left through", "progression": 1 }, { "parameter_values": [false, 270, 6], "move": "circle" }, { "parameter_values": ["ladles", "neighbors", false, 2], "move": "roll away" }], "notes": "", "hook": "Full hey double progression", "id": 1500 },
  { "title": "Diamonds Are a Baby's Choking Hazard", "choreographer_name": "Isaac Banner", "start_type": "Becket ccw", "preamble": "", "figures": [{ "parameter_values": ["quarter poussette - larks pull neighbors back then right", 4], "move": "custom" }, { "parameter_values": [true, 8], "move": "petronella", "note": "to face up and down the set (trad. 2-dancer petronella)" }, { "parameter_values": ["quarter poussette - robins pull neighbors right then back (along the set)", 4], "move": "custom", "note": "into rings with shadows" }, { "parameter_values": ["circle left 1.5 places to diamonds", 4], "move": "custom" }, { "parameter_values": [true, 8], "move": "petronella", "note": "(standard 4 person petronella)" }, { "parameter_values": ["shadows", false, true, 4], "move": "pull by dancers" }, { "parameter_values": ["gentlespoons", false, "left diagonal", 8], "move": "chain", "note": "to partners (with original neighbors/larks)", "progression": 1 }, { "parameter_values": ["gentlespoons", "", false, "half", "across", false, false, false, false, 8], "move": "hey", "note": "" }, { "parameter_values": ["gentlespoons", "", false, "half", "across", false, false, false, false, 8], "move": "hey", "note": "(one full hey in total)" }, { "parameter_values": ["partners", "none", 8], "move": "swing" }], "notes": "Don't call this one. Seriously, don't call it. This dance is a Shelly-esque crime against nature. Submit it to the next bad contra contest and take credit for it so I don't have to.", "hook": "Half poussettes to OG petronnellas to diamonds", "id": 1754 },
  { "title": "Dreaming of Michael", "choreographer_name": "Isaac Banner", "start_type": "Becket", "preamble": "", "figures": [{ "parameter_values": ["ladles", true, "partners", 8], "move": "revolving door" }, { "parameter_values": ["neighbors", "none", 8], "move": "swing" }, { "parameter_values": ["everyone", "all", "forward", "turn-alone", 8], "move": "down the hall" }, { "parameter_values": ["everyone", "all", "forward", "circle", 8], "move": "up the hall" }, { "parameter_values": ["mirrored mad robin, twos stepping in front**", 8], "move": "custom" }, { "parameter_values": [true, 8], "move": "petronella" }, { "parameter_values": ["partners", "balance", 14], "move": "swing" }, { "parameter_values": [true, 2], "move": "slide along set", "note": "to new neighbors", "progression": 1 }], "notes": "** mirrored mad robin works a little bit like the grimstock/mirror hey from wizards walk etc. with the couple above dancing down between the the inside couple from their line of 4. Dancers should still be moving aligned with their partners as in a normal mad robin, but will meet their partner in the center as they dance around their neighbors.\n\nYou can optionally teach the dancers which couples are the ones or twos during the walkthrough, but it’s less clear which is which in a becket dance.", "hook": "Lines of 4 to mirrored mad robin", "id": 1969 },
  { "title": "Elsa’s Quarter-Life Crisis", "choreographer_name": "Isaac Banner", "start_type": "Becket ccw", "preamble": "", "figures": [{ "parameter_values": ["gentlespoons", false, 540, 8], "move": "allemande" }, { "parameter_values": ["neighbors", "none", 8], "move": "swing" }, { "parameter_values": [true, "across", true, "ladles", false, "neighbors", 8], "move": "form an ocean wave" }, { "parameter_values": ["trade the wave - partners passing right, larks taking right hands and neighbors taking left hands on the other side of the set", 4], "move": "custom" }, { "parameter_values": ["neighbors", false, 90, 4], "move": "allemande", "note": "to long waves", "progression": 1 }, { "parameter_values": ["ladles", true, true, 8], "move": "box circulate" }, { "parameter_values": ["gentlespoons", true, true, 8], "move": "box circulate" }, { "parameter_values": ["ladles", true, true, 8], "move": "box circulate" }, { "parameter_values": ["partners", "none", 8], "move": "swing" }], "notes": "", "hook": "Trade the wave pivot to long waves circulate", "id": 1970 },
  { "title": "Fake Chicken", "choreographer_name": "Isaac Banner", "start_type": "improper", "preamble": "", "figures": [{ "parameter_values": ["neighbors", "balance", 16], "move": "swing" }, { "parameter_values": [true, 2], "move": "slide along set" }, { "parameter_values": [true, 270, 8], "move": "circle" }, { "parameter_values": ["shadows", "neighbors", false, true, 270, 6], "move": "square through" }, { "parameter_values": ["partners", "balance", 16], "move": "swing" }, { "parameter_values": ["ladles", true, "across", 8], "move": "chain" }, { "parameter_values": ["ladles", "", true, "half", "across", false, false, false, false, 8], "move": "hey", "note": "to face next neighbors", "progression": 1 }], "notes": "", "hook": "", "id": 1997 },
  { "title": "Frannie's Fabulous Folklife", "choreographer_name": "Isaac Banner", "start_type": "Becket", "preamble": "", "figures": [{ "parameter_values": [true, "couple", "straight", 8], "move": "slice", "progression": 1 }, { "parameter_values": [true, 360, "", 8], "move": "star" }, { "parameter_values": ["gentlespoons", 0], "move": "form long waves" }, { "parameter_values": ["gentlespoons", true, true, 8], "move": "box circulate" }, { "parameter_values": ["ladles", true, true, 8], "move": "box circulate", "note": "- robins catch right and scoop up their partner" }, { "parameter_values": ["ladles", true, 180, 4], "move": "star promenade" }, { "parameter_values": [4], "move": "butterfly whirl" }, { "parameter_values": ["gentlespoons", true, 360, 8], "move": "gyre", "note": "in the center" }, { "parameter_values": ["partners", "meltdown", 16], "move": "swing" }], "notes": "Probably don't slide the first time but hey, it's up to you", "hook": "Box circulate into unprompted star promenade", "id": 927 },
  { "title": "Galaxy Brain Balance", "choreographer_name": "Isaac Banner", "start_type": "improper", "preamble": "", "figures": [{ "parameter_values": ["neighbors", "balance", 16], "move": "swing" }, { "parameter_values": [true, 8], "move": "petronella", "note": "" }, { "parameter_values": [4], "move": "balance the ring" }, { "parameter_values": ["neighbors", 4], "move": "California twirl", "note": ", turn to face partners" }, { "parameter_values": ["partners", "balance", 16], "move": "swing" }, { "parameter_values": [4], "move": "balance the ring" }, { "parameter_values": ["neighbors Jersey twirl, turn to face partners", 4], "move": "custom" }, { "parameter_values": [true, 8], "move": "petronella", "note": "*left*", "progression": 1 }], "notes": "See [Back to Back](https://contradb.com/dances/2052) for the first chapter of this rant, but this is how [Double Balanced Brain](https://contradb.com/dances/2053) *should* have gone, if Luke Donforth had the guts (I'm joking, sorry Luke), but also curiously close to HCF by Aahz Maruch, published absolutely nowhere but sent to the Shared Weight email list back in [2013](https://lists.sharedweight.net/hyperkitty/list/contracallers@lists.sharedweight.net/message/H7IDVB7L47GOJUC73AEZ47D7ZRT7KGBU/) approximately **6 years** before Luke wrote Double Balanced Brain.....nothing is novel, everything is discovered, choreography is not the property of the choreographer, etc.", "hook": "", "id": 2054 },
  { "title": "Gentle Rewinder", "choreographer_name": "Isaac Banner", "start_type": "improper", "preamble": "", "figures": [{ "parameter_values": ["neighbors", true, 540, 8], "move": "allemande" }, { "parameter_values": ["gentlespoons", false, 540, 8], "move": "allemande" }, { "parameter_values": ["partners", "balance", 16], "move": "swing" }, { "parameter_values": ["ladles", true, "across", 8], "move": "chain" }, { "parameter_values": [true, 270, 8], "move": "circle" }, { "parameter_values": [true, 8], "move": "petronella", "progression": 1 }, { "parameter_values": [true, 360, "", 8], "move": "star" }], "notes": "", "hook": "", "id": 1996 },
  { "title": "Golden Hands", "choreographer_name": "Isaac Banner", "start_type": "improper", "preamble": "", "figures": [{ "parameter_values": ["ladles", 360, 8], "move": "mad robin", "note": "(clockwise)" }, { "parameter_values": ["ladles", false, "across", 8], "move": "chain", "note": "to partners" }, { "parameter_values": ["ladles", "", false, "half", "across", false, false, false, false, 8], "move": "hey" }, { "parameter_values": ["partners", "none", 8], "move": "swing" }, { "parameter_values": ["gentlespoons", "", false, "half", "across", false, false, false, false, 8], "move": "hey" }, { "parameter_values": [true, 360, 8], "move": "circle" }, { "parameter_values": ["ladles", true, "across", 8], "move": "chain", "note": "to neighbors (right hand chain)" }, { "parameter_values": ["ladles", 360, 8], "move": "mad robin", "note": ", on to next neighbors", "progression": 1 }], "notes": "Inspired by Abigail Golden, who noted that there weren't any dances with a robins left-hand chain (the reality is that there are a few, but they're thin on the ground). This was my take on a dance with intuitive but unique flow into both chains for both roles, so neither chain feels more or less novel than the other.", "hook": "Left- and right-hand chains, mad robin progression", "id": 2107 },
  { "title": "Grab Bag", "choreographer_name": "Isaac Banner", "start_type": "improper", "preamble": "", "figures": [{ "parameter_values": [true, 8], "move": "long lines" }, { "parameter_values": ["neighbors", "none", 8], "move": "swing", "note": "" }, { "parameter_values": ["gentlespoons", "", false, "full", "across", false, false, false, false, 16], "move": "hey", "note": "" }, { "parameter_values": ["gentlespoons", false, 2], "move": "pass by" }, { "parameter_values": ["partners", "meltdown", 14], "move": "swing", "note": "" }, { "parameter_values": ["gentlespoons", false, 540, 8], "move": "allemande" }, { "parameter_values": ["neighbors", "none", 8], "move": "swing", "progression": 1 }], "notes": "The A1 neighbor swing is a new neighbor each time after the first through the dance.", "hook": "Easy full hey, double neighbor swing", "id": 331 },
  { "title": "Gravity Assist", "choreographer_name": "Isaac Banner", "start_type": "Becket", "preamble": "", "figures": [{ "parameter_values": ["ladles", true, "across", 8], "move": "chain" }, { "parameter_values": [false, 360, "", 8], "move": "star", "progression": 1 }, { "parameter_values": ["Robins ricochet in the center, larks half sashay (quarter ricochet hey)", 4], "move": "custom", "note": "" }, { "parameter_values": ["neighbors", "none", 12], "move": "swing" }, { "parameter_values": ["gentlespoons", 360, 8], "move": "mad robin" }, { "parameter_values": ["gentlespoons", "", false, "full", "across", false, false, false, true, 16], "move": "hey" }, { "parameter_values": ["partners", "none", 8], "move": "swing" }], "notes": "Wants a tune with a 16-bar B section.", "hook": "", "id": 1430 },
  { "title": "Green Lake Twirl", "choreographer_name": "Isaac Banner", "start_type": "Becket", "preamble": "", "figures": [{ "parameter_values": [true, "couple", "none", 4], "move": "slice", "note": "", "progression": 1 }, { "parameter_values": ["gentlespoons", "neighbors", false, 4], "move": "give & take" }, { "parameter_values": ["neighbors", "none", 8], "move": "swing" }, { "parameter_values": [true, 270, 8], "move": "circle" }, { "parameter_values": ["partners", true, 450, 8], "move": "do si do", "note": "into short waves" }, { "parameter_values": ["everyone", true, false, 8], "move": "Rory O'More" }, { "parameter_values": ["everyone", true, true, 8], "move": "Rory O'More" }, { "parameter_values": ["partners", "balance", 16], "move": "swing" }], "notes": "Inspired by Cheat Lake Twirl by Perry Shafran", "hook": "Slice and take with Rory waves", "id": 548 },
  { "title": "Ham Wiggle Makes Me Giggle", "choreographer_name": "Isaac Banner", "start_type": "improper", "preamble": "", "figures": [{ "parameter_values": ["neighbors", "balance", 16], "move": "swing" }, { "parameter_values": ["across", 8], "move": "right left through" }, { "parameter_values": [true, 270, 8], "move": "circle", "note": "" }, { "parameter_values": ["ladles", "", false, "half", "across", false, false, false, false, 8], "move": "hey" }, { "parameter_values": ["partners", "none", 8], "move": "swing" }, { "parameter_values": [true, 270, 6], "move": "circle" }, { "parameter_values": ["along", true, 2], "move": "pass through" }, { "parameter_values": ["next neighbors", true, 360, 8], "move": "do si do", "progression": 1 }], "notes": "", "hook": "", "id": 1881 },
  { "title": "Higgs Boson", "choreographer_name": "Isaac Banner", "start_type": "improper", "preamble": "Starts in long waves, larks face out", "figures": [{ "parameter_values": ["ladles", true, true, 8], "move": "box circulate" }, { "parameter_values": ["gentlespoons", true, true, 8], "move": "box circulate" }, { "parameter_values": ["neighbors", "balance", 16], "move": "swing" }, { "parameter_values": [true, 270, 8], "move": "circle" }, { "parameter_values": ["partners", "none", 8], "move": "swing" }, { "parameter_values": [true, "across", true, "ladles", false, "neighbors", 8], "move": "form an ocean wave" }, { "parameter_values": ["ladles", false, 180, 2], "move": "allemande" }, { "parameter_values": ["along", true, 2], "move": "pass through", "progression": 1 }, { "parameter_values": ["next neighbors", true, 270, 4], "move": "allemande", "note": "to long waves" }], "notes": "Based on Furthermore by Scott Higgs, but with a box circulate, rather than the original dances Rory spins, and other fiddling to sort out the positional changes that creates.", "hook": "Box circulate with pass the ocean progression.", "id": 876 },
  { "title": "Hotpoint Deluxe", "choreographer_name": "Isaac Banner", "start_type": "Becket ccw", "preamble": "", "figures": [{ "parameter_values": ["gentlespoons", false, 540, 8], "move": "allemande" }, { "parameter_values": ["neighbors", "none", 8], "move": "swing" }, { "parameter_values": [true, "across", true, "ladles", false, "neighbors", 8], "move": "form an ocean wave" }, { "parameter_values": ["Do the hotpoint special progression, robins in front", 8], "move": "custom", "progression": 1 }, { "parameter_values": [true, "across", true, "gentlespoons", false, "partners", 8], "move": "form an ocean wave" }, { "parameter_values": ["along", true, 2], "move": "pass through" }, { "parameter_values": ["shadows", false, 360, 6], "move": "allemande" }, { "parameter_values": ["partners", "balance", 16], "move": "swing" }], "notes": "Inspired by \"Hotpoint Special\" by Joseph Pimentel", "hook": "Hotpoint ocean wave to ocean wave", "id": 1471 },
  { "title": "I Drove to Portland for Tacos", "choreographer_name": "Isaac Banner", "start_type": "improper", "preamble": "", "figures": [{ "parameter_values": ["neighbors", true, 360, 8], "move": "do si do" }, { "parameter_values": ["neighbors", "none", 8], "move": "swing" }, { "parameter_values": ["ladles", true, 540, 8], "move": "allemande" }, { "parameter_values": ["partners", "none", 8], "move": "swing" }, { "parameter_values": [true, 8], "move": "long lines", "note": ", robins roll away partners left to right on the way back" }, { "parameter_values": [true, 270, 8], "move": "circle" }, { "parameter_values": ["across", 8], "move": "right left through" }, { "parameter_values": [false, 360, "", 8], "move": "star", "note": "to new neighbors", "progression": 1 }], "notes": "", "hook": "", "id": 1972 },
  { "title": "Keep Left at the Frock", "choreographer_name": "Isaac Banner", "start_type": "improper", "preamble": "Ensure that dancers understand the flow and mechanics of a left-handed chain ahead of the full walkthrough", "figures": [{ "parameter_values": ["neighbors", "meltdown", 16], "move": "swing" }, { "parameter_values": ["gentlespoons", 360, 8], "move": "mad robin" }, { "parameter_values": [0.5, "ladles", "partners", true, 8], "move": "poussette" }, { "parameter_values": ["ladles", "", false, "gentlespoons%%1", "across", false, false, false, false, 2], "move": "hey", "note": "" }, { "parameter_values": ["gentlespoons", false, 360, 6], "move": "allemande", "note": "to partner" }, { "parameter_values": ["partners", "none", 8], "move": "swing" }, { "parameter_values": ["gentlespoons", false, "across", 8], "move": "chain", "note": "pull by left" }, { "parameter_values": ["gentlespoons", "", false, "half", "across", false, false, false, false, 8], "move": "hey", "note": "to new neighbors", "progression": 1 }], "notes": "B1 half hey is a broken hey - for the robins it's a half hey but the larks never cross. When the larks meet in the center the first time, they allemande left once around back to their partner.\n\nWritten for Greg Frock in September of 2022.", "hook": "Extended flowing travel, larks LH chain", "id": 1813 },
  { "title": "Lake City Crossing", "choreographer_name": "Isaac Banner", "start_type": "improper", "preamble": "", "figures": [{ "parameter_values": ["neighbors", true, 540, 8], "move": "allemande", "note": "to long waves, larks face in" }, { "parameter_values": ["gentlespoons", true, true, 8], "move": "box circulate" }, { "parameter_values": ["ladles", true, true, 8], "move": "box circulate" }, { "parameter_values": ["neighbors", "none", 8], "move": "swing" }, { "parameter_values": ["gentlespoons", "", false, "half", "across", false, true, false, false, 8], "move": "hey" }, { "parameter_values": ["partners", "none", 8], "move": "swing" }, { "parameter_values": ["ladles", true, "across", 8], "move": "chain" }, { "parameter_values": [false, 360, "", 8], "move": "star", "progression": 1 }], "notes": "", "hook": "Simpler box circulate with a ricochet hey", "id": 1498 },
  { "title": "Last Hey", "choreographer_name": "Isaac Banner", "start_type": "Becket", "preamble": "", "figures": [{ "parameter_values": [true, 270, 8], "move": "circle" }, { "parameter_values": [4], "move": "balance the ring" }, { "parameter_values": ["along", true, 4], "move": "pass through", "progression": 1 }, { "parameter_values": ["ladles", false, 540, 8], "move": "allemande", "note": "(new robins)" }, { "parameter_values": ["everyone", 4], "move": "balance", "note": "short waves" }, { "parameter_values": ["partners", true, 270, 4], "move": "allemande" }, { "parameter_values": ["ladles", "", false, "full", "across", false, false, false, false, 16], "move": "hey" }, { "parameter_values": ["partners", "balance", 16], "move": "swing" }], "notes": "Based on Paul Balliet's First Hey, shifted and with one phrase changed. Offers an opening that works much better with a barn-burner of a tune, with a runaway B section. Manages the energy throughout the sequence better than Paul's original dance, in my opinion. At the very least it offers a distinctly more driving and chunky feel compared to the original.", "hook": "", "id": 387 },
  { "title": "Liam Left Me for London", "choreographer_name": "Isaac Banner", "start_type": "Becket", "preamble": "", "figures": [{ "parameter_values": ["ladles", true, "across", 8], "move": "chain" }, { "parameter_values": ["ladles", true, 360, 8], "move": "gyre", "note": "and walk on to next neighbors", "progression": 1 }, { "parameter_values": ["next neighbors", "balance", 16], "move": "swing" }, { "parameter_values": ["gentlespoons", "", false, "half", "across", false, false, false, false, 8], "move": "hey", "note": ", end in long waves w/ larks facing in" }, { "parameter_values": ["gentlespoons", true, true, 8], "move": "box circulate" }, { "parameter_values": ["ladles", true, true, 8], "move": "box circulate", "note": "and ricochet back to partners" }, { "parameter_values": ["partners", "none", 8], "move": "swing" }], "notes": "Robins ricochet in B2 should be left-to-right, similar to a ricochet hey", "hook": "Ricochet box circulate to partner swing", "id": 2049 },
  { "title": "Lost at Sea", "choreographer_name": "Isaac Banner", "start_type": "Becket", "preamble": "", "figures": [{ "parameter_values": [true, "across", true, "ladles", false, "partners", 8], "move": "form an ocean wave" }, { "parameter_values": ["along", true, 2], "move": "pass through" }, { "parameter_values": ["shadows", true, 90, 2], "move": "allemande" }, { "parameter_values": ["gentlespoons", 0], "move": "form long waves" }, { "parameter_values": ["everyone", 4], "move": "balance", "note": "long waves" }, { "parameter_values": ["gentlespoons", false, true, 4], "move": "box circulate" }, { "parameter_values": ["neighbors", true, 90, 2], "move": "gyre" }, { "parameter_values": ["along", true, 2], "move": "pass through", "progression": 1 }, { "parameter_values": ["next neighbors", "none", 8], "move": "swing" }, { "parameter_values": [true, 270, 6], "move": "circle" }, { "parameter_values": ["shadows", true, 540, 10], "move": "do si do" }, { "parameter_values": ["partners", "balance", 16], "move": "swing" }], "notes": "", "hook": "", "id": 1999 },
  { "title": "Magnetic Waves", "choreographer_name": "Isaac Banner", "start_type": "Becket", "preamble": "", "figures": [{ "parameter_values": ["gentlespoons", "", false, "ladles%%2", "across", false, false, false, false, 14], "move": "hey" }, { "parameter_values": ["ladles", false, 90, 2], "move": "allemande", "note": "to short waves" }, { "parameter_values": [false, "across", true, "ladles", false, "partners", 4], "move": "form an ocean wave" }, { "parameter_values": ["partners", true, 180, 2], "move": "allemande" }, { "parameter_values": ["gentlespoons", false, false, 2], "move": "pull by dancers" }, { "parameter_values": ["neighbors", "none", 8], "move": "swing" }, { "parameter_values": [true, "across", true, "ladles", false, "neighbors", 8], "move": "form an ocean wave" }, { "parameter_values": ["along", true, 2], "move": "pass through", "progression": 1 }, { "parameter_values": ["ladles", 360, 6], "move": "mad robin" }, { "parameter_values": ["single-file circle left 1 place", 2], "move": "custom" }, { "parameter_values": ["partners", "meltdown", 14], "move": "swing" }], "notes": "", "hook": "Pass the ocean to mad robin progression", "id": 1987 },
  { "title": "March for Andrea", "choreographer_name": "Isaac Banner", "start_type": "Becket", "preamble": "Andrea Nettleton told me she wished callers would do more down the halls, but all the options in my box were pretty basic and I wanted something that used it as less of an \"away we go\" and more of a buildup. ", "figures": [{ "parameter_values": ["ladles", true, "partners", 8], "move": "revolving door" }, { "parameter_values": ["neighbors", "none", 8], "move": "swing", "note": "and end facing down" }, { "parameter_values": ["everyone", "all", "forward", "turn-alone", 8], "move": "down the hall" }, { "parameter_values": ["everyone", "all", "forward", "circle", 8], "move": "up the hall" }, { "parameter_values": [4], "move": "balance the ring" }, { "parameter_values": ["partners", 4], "move": "California twirl", "progression": 1 }, { "parameter_values": [4], "move": "balance the ring" }, { "parameter_values": ["gentlespoons", "neighbors", true, 4], "move": "roll away" }, { "parameter_values": [4], "move": "balance the ring" }, { "parameter_values": ["gentlespoons", "partners", false, 4], "move": "give & take" }, { "parameter_values": ["partners", "none", 8], "move": "swing" }], "notes": "", "hook": "Down the hall without the default circle left", "id": 685 },
  { "title": "Napkin #11", "choreographer_name": "Isaac Banner", "start_type": "improper", "preamble": "", "figures": [{ "parameter_values": ["neighbors", false, false, 4], "move": "box the gnat" }, { "parameter_values": ["ladles", false, true, 4], "move": "pull by dancers" }, { "parameter_values": ["partners", "none", 8], "move": "swing" }, { "parameter_values": ["gentlespoons", false, 540, 8], "move": "allemande" }, { "parameter_values": ["neighbors", "none", 8], "move": "swing" }, { "parameter_values": ["ladles", true, "across", 8], "move": "chain" }, { "parameter_values": [false, 4], "move": "long lines" }, { "parameter_values": ["ladles", "partners", false, 4], "move": "roll away", "note": "on the way back" }, { "parameter_values": [true, 270, 8], "move": "circle" }, { "parameter_values": ["neighbors", false, true, 4], "move": "box the gnat" }, { "parameter_values": ["neighbors", false, true, 4], "move": "pull by dancers", "progression": 1 }], "notes": "", "hook": "No-balance box the gnat to swat the flea w/ next", "id": 2050 },
  { "title": "Napkin #12", "choreographer_name": "Isaac Banner", "start_type": "improper", "preamble": "", "figures": [{ "parameter_values": ["neighbors", true, true, 8], "move": "box the gnat" }, { "parameter_values": ["gentlespoons", false, 540, 8], "move": "allemande" }, { "parameter_values": ["partners", "ladles", true, "half", "across", false, true, false, false, 8], "move": "hey" }, { "parameter_values": ["ladles", false, "across", 8], "move": "chain", "note": "to partners" }, { "parameter_values": ["robins ricochet, larks slide left", 4], "move": "custom", "note": "" }, { "parameter_values": ["partners", "none", 12], "move": "swing" }, { "parameter_values": ["gentlespoons", "", false, "half", "across", false, true, false, false, 8], "move": "hey", "note": "and catch left hands" }, { "parameter_values": [false, 360, "", 8], "move": "star", "note": ", larks fall in behind neighbors", "progression": 1 }], "notes": "", "hook": "", "id": 2112 },
  { "title": "Napkin #8", "choreographer_name": "Isaac Banner", "start_type": "improper", "preamble": "", "figures": [{ "parameter_values": [true, 8], "move": "petronella", "note": "right, end facing shadows" }, { "parameter_values": [true, 8], "move": "petronella", "note": "left" }, { "parameter_values": ["neighbors", "balance", 16], "move": "swing" }, { "parameter_values": ["gentlespoons", false, false, 4], "move": "pull by dancers", "note": "along right diagonal", "progression": 1 }, { "parameter_values": ["partners", "meltdown", 12], "move": "swing" }, { "parameter_values": [true, 270, 8], "move": "circle" }, { "parameter_values": ["neighbors", true, 360, 8], "move": "do si do" }], "notes": "", "hook": "Petronella right to shadow petronella left", "id": 1981 },
  { "title": "New Year, Same Old Charlie", "choreographer_name": "Isaac Banner", "start_type": "improper", "preamble": "", "figures": [{ "parameter_values": ["neighbors", "balance", 16], "move": "swing", "note": ", end facing down the hall" }, { "parameter_values": ["everyone", "all", "forward", "turn-alone", 8], "move": "down the hall" }, { "parameter_values": ["everyone", "all", "forward", "", 8], "move": "up the hall", "note": "and ones cast down one couple to new rings", "progression": 1 }, { "parameter_values": [true, 8], "move": "petronella" }, { "parameter_values": ["partners", "none", 8], "move": "swing" }, { "parameter_values": [true, 8], "move": "petronella" }, { "parameter_values": [4], "move": "balance the ring" }, { "parameter_values": ["partners", 4], "move": "California twirl", "progression": 1 }], "notes": "A2 cast down is mirrored with the active couple turning over their outside shoulders to drop down into a new ring of foot while the inactive couples finish moving up the hall.", "hook": "Cast down to rings balance, petronella to swing", "id": 1935 },
  { "title": "Not My Second Rodeo", "choreographer_name": "Isaac Banner", "start_type": "improper", "preamble": "", "figures": [{ "parameter_values": ["neighbors", "balance", 16], "move": "swing" }, { "parameter_values": ["gentlespoons", "", false, "half", "across", false, false, false, false, 8], "move": "hey" }, { "parameter_values": ["gentlespoons", false, 540, 8], "move": "allemande" }, { "parameter_values": ["partners", "meltdown", 16], "move": "swing" }, { "parameter_values": [true, 270, 8], "move": "circle" }, { "parameter_values": ["along", true, 0], "move": "pass through", "progression": 1 }, { "parameter_values": ["next neighbors", true, 360, 8], "move": "do si do" }], "notes": "Kind of but not really The Second Time Around by Jim Kitch. Hey-to-allemande offers a refreshing broken-hey-ish redux of allemande-to-hey and creates an illusion of less inactivity in the robin's role.", "hook": "", "id": 413 },
  { "title": "On The Other Foot", "choreographer_name": "Isaac Banner", "start_type": "Becket", "preamble": "", "figures": [{ "parameter_values": ["ladles", true, "partners", 6], "move": "revolving door", "note": "" }, { "parameter_values": ["ladles", true, 180, 2], "move": "allemande", "note": "to take hands in a long wave facing their partner" }, { "parameter_values": ["ladles", true, true, 8], "move": "Rory O'More", "note": "into a diamond with your shadow" }, { "parameter_values": [true, 8], "move": "petronella", "note": "the diamond" }, { "parameter_values": ["gentlespoons", false, false, false, 0], "move": "form a long wave", "note": "facing the same direction they were in the diamond" }, { "parameter_values": ["gentlespoons", true, false, 8], "move": "Rory O'More", "progression": 1 }, { "parameter_values": ["everyone", 4], "move": "balance", "note": "the diamond" }, { "parameter_values": ["gentlespoons", false, 270, 4], "move": "allemande" }, { "parameter_values": ["neighbors", "none", 8], "move": "swing" }, { "parameter_values": [true, 270, 6], "move": "circle", "note": "" }, { "parameter_values": ["partners", "none", 10], "move": "swing" }], "notes": "In the shadow diamond, larks have their shadow in their left hand (robins have their shadow in their right) \n\nInspired unintentionally by a foggy memory of Goody One Shoe and an unhappiness with other existing diamond-to-swing dances.", "hook": "Waves to diamonds to waves to diamonds", "id": 519 },
  { "title": "Once More With Feeling", "choreographer_name": "Isaac Banner", "start_type": "improper", "preamble": "", "figures": [{ "parameter_values": ["neighbors", 4], "move": "balance", "note": "right hand" }, { "parameter_values": ["neighbors", false, true, 4], "move": "box the gnat" }, { "parameter_values": ["gentlespoons", false, 540, 8], "move": "allemande" }, { "parameter_values": ["partners", "balance", 16], "move": "swing" }, { "parameter_values": [true, 270, 8], "move": "circle" }, { "parameter_values": ["neighbors", "none", 8], "move": "swing" }, { "parameter_values": [true, 8], "move": "petronella" }, { "parameter_values": [true, 8], "move": "petronella", "note": "and turn to face new neighbors", "progression": 1 }], "notes": "", "hook": "", "id": 333 },
  { "title": "One Fish, Two Fish, Right and Left Through Fish", "choreographer_name": "Isaac Banner", "start_type": "Becket", "preamble": "", "figures": [{ "parameter_values": [true, 270, 8], "move": "circle", "note": "and face across" }, { "parameter_values": [4], "move": "balance the ring", "note": "" }, { "parameter_values": [true, "across", false, "gentlespoons", false, "neighbors", 4], "move": "form an ocean wave", "note": "" }, { "parameter_values": ["everyone", 4], "move": "balance", "note": "short waves forward/back" }, { "parameter_values": ["along", true, 2], "move": "pass through", "note": "", "progression": 1 }, { "parameter_values": ["next neighbors", "none", 10], "move": "swing" }, { "parameter_values": ["across", 8], "move": "right left through" }, { "parameter_values": ["ladles", true, 270, 4], "move": "allemande", "note": "", "progression": 1 }, { "parameter_values": ["ladles", false, 270, 4], "move": "allemande", "note": "+" }, { "parameter_values": ["partners", "balance", 16], "move": "swing" }], "notes": "The name started as a joke until Ron Blechner egged me on to write an actual dance.\n\n+this is your third robin\n\nThe pivotal place where it can all fall to pieces is the pass the ocean - if dancers aren't paying attention they'll absentmindedly pass through up/down and everything will collapse in on itself.", "hook": "Double progressed ocean waves and a salmon ladder ", "id": 416 },
  { "title": "O’More for Me, Then", "choreographer_name": "Isaac Banner", "start_type": "improper", "preamble": "", "figures": [{ "parameter_values": [true, 8], "move": "long lines" }, { "parameter_values": ["ladles", false, false, 2], "move": "pull by dancers" }, { "parameter_values": ["partners", true, 270, 6], "move": "allemande", "note": "to long waves, larks facing out" }, { "parameter_values": ["everyone", true, false, 8], "move": "Rory O'More" }, { "parameter_values": ["everyone", true, true, 8], "move": "Rory O'More" }, { "parameter_values": ["partners", "balance", 16], "move": "swing" }, { "parameter_values": [true, 270, 8], "move": "circle" }, { "parameter_values": ["neighbors", "none", 8], "move": "swing", "progression": 1 }], "notes": "Similar to Less is More by Melanie Axel-Lute, but de-becketized and with partners in long waves to give more time for interaction.", "hook": "Simple Rory slides to partner swing", "id": 1980 },
  { "title": "Peace Is Still the Way", "choreographer_name": "Isaac Banner", "start_type": "Becket", "preamble": "", "figures": [{ "parameter_values": [true, 360, 8], "move": "circle" }, { "parameter_values": ["partners", true, 540, 8], "move": "allemande", "note": "to long waves" }, { "parameter_values": ["ladles", true, true, 8], "move": "box circulate" }, { "parameter_values": ["gentlespoons", true, true, 8], "move": "box circulate", "note": "- larks catch RH, scoop up partner" }, { "parameter_values": ["gentlespoons", true, 270, 6], "move": "star promenade" }, { "parameter_values": ["next robins catch left", 0], "move": "custom" }, { "parameter_values": ["ladles", false, 270, 6], "move": "star promenade", "note": "" }, { "parameter_values": [4], "move": "butterfly whirl" }, { "parameter_values": ["gentlespoons", true, 360, 6], "move": "do si do" }, { "parameter_values": ["partners", "none", 10], "move": "swing" }], "notes": "", "hook": "Box circulate into unprompted star promenade", "id": 869 },
  { "title": "Pebbles in my Boots", "choreographer_name": "Isaac Banner", "start_type": "improper", "preamble": "Starts in short waves, neighbors in right hand", "figures": [{ "parameter_values": ["everyone", 4], "move": "balance", "note": "short waves forward/back" }, { "parameter_values": ["along", true, 2], "move": "pass through", "progression": 1 }, { "parameter_values": ["next neighbors", true, 90, 2], "move": "allemande", "note": "to long waves" }, { "parameter_values": ["gentlespoons", true, true, 8], "move": "box circulate" }, { "parameter_values": ["partners", "balance", 16], "move": "swing" }, { "parameter_values": ["ladles", true, 540, 8], "move": "allemande" }, { "parameter_values": ["neighbors", "none", 8], "move": "swing" }, { "parameter_values": [true, 360, 8], "move": "circle" }, { "parameter_values": [4], "move": "balance the ring" }, { "parameter_values": [true, "across", false, "ladles", false, "neighbors", 4], "move": "form an ocean wave" }], "notes": "", "hook": "Short waves to long waves circulate", "id": 1875 },
  { "title": "Red Beard's Redder Beard", "choreographer_name": "Isaac Banner", "start_type": "Becket", "preamble": "", "figures": [{ "parameter_values": ["ladles", true, 540, 8], "move": "allemande", "note": "while larks turn over left shoulder and cast off to meet prev neighbors" }, { "parameter_values": ["prev neighbors", "none", 8], "move": "swing" }, { "parameter_values": [true, 8], "move": "long lines" }, { "parameter_values": ["neighbors", "across", false, 8], "move": "promenade", "note": "across and j-hook left to face partners across" }, { "parameter_values": [true, "across", true, "ladles", false, "neighbors", 8], "move": "form an ocean wave" }, { "parameter_values": ["along", true, 2], "move": "pass through" }, { "parameter_values": ["ladles", 360, 6], "move": "mad robin" }, { "parameter_values": ["ladles", true, 2], "move": "pass by", "note": "across" }, { "parameter_values": ["partners", "meltdown", 12], "move": "swing" }, { "parameter_values": [true, 2], "move": "slide along set", "progression": 1 }], "notes": "Have dancers identify their opposite-role dancer on the right diagonal before starting. A1 has the larks cast off down the set to that identified dancer for a swing. Each other time through, it will be the neighbor they mad robin with.\n\nThe pass through in the B1 is just undoing the reverse-progression in the A section. The only real progression is the slide left in the B2. In more detail -  \n* A1 - End the previous neighbor swing across from a shadow  \n* A2 - The j-hook promenade leaves dancers facing their partners  \n* B1 - The pass through takes dancers from their previous neighbors back to their current neighbors  \n* B2 - With the slide left, dancers finally progress on to new neighbors  \n\n*Based on Red Beard Reel by Bob Isaacs, now even redder and more beard-y.*", "hook": "J-hook to ocean waves to mad robin to swings", "id": 1756 },
  { "title": "Redwood", "choreographer_name": "Isaac Banner", "start_type": "improper", "preamble": "Have dancers note their direction of travel.", "figures": [{ "parameter_values": ["neighbors", true, 180, 4], "move": "gyre" }, { "parameter_values": ["single-file promenade clockwise across the set", 4], "move": "custom", "note": ", larks facing neighbors" }, { "parameter_values": ["neighbors", "none", 8], "move": "swing" }, { "parameter_values": [true, 180, 4], "move": "circle", "note": "and form long waves - larks face in, robins face out" }, { "parameter_values": ["gentlespoons", true, true, 8], "move": "box circulate" }, { "parameter_values": ["ladles", 0], "move": "form long waves" }, { "parameter_values": ["everyone", 4], "move": "balance", "note": "the wave" }, { "parameter_values": ["ladles", false, true, 4], "move": "box circulate", "note": "and follow partners across the set" }, { "parameter_values": ["partners", "none", 12], "move": "swing" }, { "parameter_values": [true, "across", true, "ladles", false, "partners", 8], "move": "form an ocean wave" }, { "parameter_values": ["ladles", false, 270, 4], "move": "allemande" }, { "parameter_values": ["trade the wave and pass through left - partners pass right across, neighbors pass left along", 4], "move": "custom", "note": "", "progression": 1 }], "notes": "**Trade the wave**: have dancers note their partner's position in the B2 ocean wave - they will travel into their partner's place in the wave, facing the opposite direction (their direction of travel). Dancers face across the set, pass their partner by the right across, and step back into the wave offering left hands to their neighbors (in this case, dancers don't retake the wave, passing through instead, but a teaching wave might help dancers orient themselves during the first walkthrough).\n\nInspired by a figure pair introduced to me by [nc Krantz-Fire](https://contradb.com/choreographers/416), I wanted to play around with a circle left 2 places to long waves circulate. Pushing the balance to the back beat creates some interesting space to work with and presents the move in a way that feels fresh. I've wanted to toy with circulate-chase figures for a little while, similar to the flow of Chris Page's [Heart of Joy](https://contradb.com/dances/676) and the back beat balances gave the figure a bit more space to breathe.  \nCredit to Will Mentor for introducing me to the \"Trade the Wave\" figure, the cross-set trade feels similar to a box circulate and matches up nicely with the core of the dance.", "hook": "Heart of Joy circulates", "id": 2060 },
  { "title": "Return to Portland", "choreographer_name": "Isaac Banner", "start_type": "improper", "preamble": "Starts 1s below 2s, don’t need to teach it that way", "figures": [{ "parameter_values": ["ladles", true, 360, 8], "move": "allemande" }, { "parameter_values": ["neighbors", "none", 8], "move": "swing", "progression": 1 }, { "parameter_values": [false, 4], "move": "long lines" }, { "parameter_values": ["gentlespoons", "next neighbors", true, 4], "move": "roll away", "note": "on the way back" }, { "parameter_values": ["gentlespoons", false, 540, 8], "move": "allemande" }, { "parameter_values": ["partners", "balance", 16], "move": "swing" }, { "parameter_values": ["across", 8], "move": "right left through" }, { "parameter_values": ["ladles", true, "across", 8], "move": "chain" }], "notes": "", "hook": "Simple R+L thru to chain", "id": 1924 },
  { "title": "Ro's and Columns", "choreographer_name": "Isaac Banner", "start_type": "improper", "preamble": "Warn dancers this dance was written in jest, so as to appropriately set their expectations ", "figures": [{ "parameter_values": [true, 8], "move": "long lines" }, { "parameter_values": ["neighbors", "none", 8], "move": "swing", "note": ", end facing down the hall" }, { "parameter_values": ["everyone", "all", "forward", "", 8], "move": "down the hall", "note": ", twos stop early and ones walk on to new neighbors", "progression": 1 }, { "parameter_values": ["next neighbors", "none", 8], "move": "swing" }, { "parameter_values": [false, 4], "move": "long lines", "note": "" }, { "parameter_values": ["gentlespoons", "partners", false, 4], "move": "give & take" }, { "parameter_values": ["partners", "none", 8], "move": "swing", "note": ", end facing up the hall" }, { "parameter_values": ["everyone", "all", "forward", "circle", 8], "move": "up the hall" }, { "parameter_values": ["gentlespoons", "neighbors", false, 4], "move": "give & take" }, { "parameter_values": ["neighbors", "none", 4], "move": "swing", "progression": 1 }], "notes": "Written after years of constant demands from Rochelle Starrett, don’t get mad at me if dancers revolt.", "hook": "Double progression long lines overload joke dance", "id": 2047 },
  { "title": "Robin Shall Restore Amends", "choreographer_name": "Isaac Banner", "start_type": "improper", "preamble": "A dance re-imagining of A Midsummer Night's Dream, written for Rosalie Banner on her 20th birthday. \"Give me your hands [four], may we be friends, and Robin shall restore amends.\"", "figures": [{ "parameter_values": [true, 8], "move": "petronella", "note": "to long waves, larks face out" }, { "parameter_values": ["ladles", true, true, 8], "move": "box circulate", "note": "" }, { "parameter_values": ["gentlespoons", true, true, 8], "move": "box circulate" }, { "parameter_values": ["everyone", true, false, 8], "move": "Rory O'More" }, { "parameter_values": ["partners", "none", 16], "move": "swing" }, { "parameter_values": [true, 270, 8], "move": "circle" }, { "parameter_values": [4], "move": "balance the ring" }, { "parameter_values": ["along", true, 4], "move": "pass through", "progression": 1 }], "notes": "When teaching this one I make a point of identifying who is chasing whom in the box circulate, otherwise dancers will often find themselves a bit lost when they circulate away from their partner. ", "hook": "Reunion dance with petronella to box circulate.", "id": 329 },
  { "title": "Rory O'Most", "choreographer_name": "Isaac Banner", "start_type": "improper", "preamble": "Long waves, larks face out", "figures": [{ "parameter_values": ["everyone", true, false, 8], "move": "Rory O'More" }, { "parameter_values": ["everyone", true, true, 8], "move": "Rory O'More" }, { "parameter_values": ["everyone", true, false, 8], "move": "Rory O'More", "progression": 1 }, { "parameter_values": ["next neighbors", "none", 8], "move": "swing" }, { "parameter_values": ["gentlespoons", false, 540, 8], "move": "allemande", "note": "" }, { "parameter_values": ["partners", "none", 8], "move": "swing" }, { "parameter_values": ["ladles", true, "across", 8], "move": "chain" }, { "parameter_values": ["ladles", "", true, "half", "across", false, false, false, false, 8], "move": "hey", "note": "into long waves, right hand to new neighbors" }], "notes": "", "hook": "catches out of third Rory O'Moore spin", "id": 1753 },
  { "title": "Roses on the Road", "choreographer_name": "Isaac Banner", "start_type": "Becket", "preamble": "Identify neighbors number 2 and 3 before the walk-through.", "figures": [{ "parameter_values": ["ladles", true, "left diagonal", 8], "move": "chain", "note": "to next neighbors", "progression": 1 }, { "parameter_values": [false, 360, "", 8], "move": "star", "progression": 1 }, { "parameter_values": ["3rd neighbors", "balance", 16], "move": "swing" }, { "parameter_values": [true, 270, 6], "move": "circle" }, { "parameter_values": ["along", true, 2], "move": "pass through" }, { "parameter_values": ["partners", true, 360, 8], "move": "do si do" }, { "parameter_values": ["partners", "balance", 16], "move": "swing" }], "notes": "In addition to marking out neighbors 2 and 3 ahead of time, it helps to identify the dancer's shadow in the star/circle post-chain.", "hook": "Double progression Baby Rose rehash/reunion", "id": 772 },
  { "title": "Safe and Sound", "choreographer_name": "Isaac Banner", "start_type": "Becket", "preamble": "", "figures": [{ "parameter_values": ["gentlespoons", "", false, "neighbors%%2", "across", false, false, false, false, 12], "move": "hey" }, { "parameter_values": ["neighbors", true, 180, 4], "move": "gyre" }, { "parameter_values": ["neighbors", "meltdown", 16], "move": "swing" }, { "parameter_values": [true, 270, 6], "move": "circle" }, { "parameter_values": ["single-file promenade along the set to new neighbors", 4], "move": "custom", "progression": 1 }, { "parameter_values": ["single-file circle left 2 places", 4], "move": "custom" }, { "parameter_values": ["partners", true, 180, 2], "move": "gyre" }, { "parameter_values": ["single-file circle left 2 places", 4], "move": "custom" }, { "parameter_values": ["partners", "meltdown", 12], "move": "swing" }], "notes": "Encourage spatially-aware traveling eye contact between dancers and their partners throughout the B1 up to the partner swing.\n\nFor a simpler dance, replace the single-file movement with a slide left along the set and a circle left 4 places, ending with the partners meltdown swing in the B2.", "hook": "Extended traveling partner eye contact", "id": 2011 },
  { "title": "Simple Circulation", "choreographer_name": "Isaac Banner", "start_type": "improper", "preamble": "", "figures": [{ "parameter_values": ["neighbors", "balance", 16], "move": "swing" }, { "parameter_values": ["ladles", true, false, true, 8], "move": "form a long wave" }, { "parameter_values": ["robins walk forward to cross the set while larks dance in to a  wave, taking their neighbors place - balance the wave", 8], "move": "custom" }, { "parameter_values": ["gentlespoons", false, 180, 4], "move": "allemande" }, { "parameter_values": ["partners", "none", 12], "move": "swing" }, { "parameter_values": ["ladles", true, "across", 8], "move": "chain" }, { "parameter_values": [false, 360, "", 8], "move": "star", "progression": 1 }], "notes": "", "hook": "long waves with a proto-circulate", "id": 1995 },
  { "title": "Sleepy Sam’s Late Night Jam", "choreographer_name": "Isaac Banner", "start_type": "Becket", "preamble": "", "figures": [{ "parameter_values": [true, "couple", "none", 4], "move": "slice", "progression": 1 }, { "parameter_values": ["ladles", "neighbors", false, 4], "move": "give & take" }, { "parameter_values": ["neighbors", "none", 8], "move": "swing" }, { "parameter_values": ["neighbors", "across", false, 8], "move": "promenade", "note": "and hook left one couple to face shadows" }, { "parameter_values": ["across", 8], "move": "right left through", "note": "" }, { "parameter_values": [false, 270, 8], "move": "circle", "note": "" }, { "parameter_values": ["partners", false, "", 8], "move": "zig zag" }, { "parameter_values": [0.5, "gentlespoons", "neighbors", true, 6], "move": "poussette", "note": "" }, { "parameter_values": ["partners", "none", 8], "move": "swing" }], "notes": "Give & take straight across first time through", "hook": "Smooth zig zag to poussette", "id": 1861 },
  { "title": "Snowbirds", "choreographer_name": "Isaac Banner", "start_type": "Becket", "preamble": "", "figures": [{ "parameter_values": ["ladles", "", true, "half", "across", false, false, false, false, 8], "move": "hey" }, { "parameter_values": ["ladles", true, "across", 8], "move": "chain", "note": ", larks roll away to long waves", "progression": 1 }, { "parameter_values": ["gentlespoons", true, true, 8], "move": "box circulate" }, { "parameter_values": ["ladles", true, true, 8], "move": "box circulate" }, { "parameter_values": ["gentlespoons", 360, 8], "move": "mad robin" }, { "parameter_values": ["Single-file circle left 3/4", 8], "move": "custom" }, { "parameter_values": ["partners", "meltdown", 16], "move": "swing" }], "notes": "", "hook": "Circulate into Mad Robin", "id": 1133 },
  { "title": "Stars in the Wildfire", "choreographer_name": "Isaac Banner", "start_type": "improper", "preamble": "", "figures": [{ "parameter_values": [true, 360, "", 8], "move": "star", "note": ", larks push off to end in short waves with neighbors in right hands" }, { "parameter_values": ["everyone", 4], "move": "balance", "note": "short waves" }, { "parameter_values": ["neighbors", true, 180, 2], "move": "allemande" }, { "parameter_values": ["gentlespoons", false, 180, 2], "move": "allemande" }, { "parameter_values": ["partners", true, true, 8], "move": "box the gnat" }, { "parameter_values": ["partners", "", true, "half", "across", false, false, false, false, 8], "move": "hey" }, { "parameter_values": ["partners", "balance", 16], "move": "swing" }, { "parameter_values": ["ladles", true, "across", 8], "move": "chain" }, { "parameter_values": [false, 360, "", 8], "move": "star", "note": "to next neighbors", "progression": 1 }], "notes": "", "hook": "Star to star to short waves", "id": 1939 },
  { "title": "Summer in Summerland", "choreographer_name": "Isaac Banner", "start_type": "Becket ccw", "preamble": "", "figures": [{ "parameter_values": ["ladles", true, 540, 8], "move": "allemande" }, { "parameter_values": ["neighbors", "none", 8], "move": "swing" }, { "parameter_values": ["ladles", true, "left diagonal", 8], "move": "chain", "note": "and larks turn/roll their shadows a little bit more to offer left hands in a short wave with the robins in the center", "progression": 1 }, { "parameter_values": [false, "across", true, "ladles", true, "shadows", 4], "move": "form an ocean wave" }, { "parameter_values": ["along", true, 2], "move": "pass through" }, { "parameter_values": ["partners", false, 90, 2], "move": "gyre" }, { "parameter_values": ["partners", "", false, "full", "across", false, false, false, false, 16], "move": "hey" }, { "parameter_values": ["partners", "balance", 16], "move": "swing" }], "notes": "", "hook": "", "id": 1984 },
  { "title": "Swapportunities Abound", "choreographer_name": "Isaac Banner", "start_type": "Becket", "preamble": "", "figures": [{ "parameter_values": [true, 8], "move": "long lines" }, { "parameter_values": [true, 270, 8], "move": "circle" }, { "parameter_values": [0.5, "gentlespoons", "partners", true, 8], "move": "poussette" }, { "parameter_values": ["neighbors", "none", 8], "move": "swing" }, { "parameter_values": ["gentlespoons", 360, 8], "move": "mad robin", "note": ", face next neighbors", "progression": 1 }, { "parameter_values": [true, 8], "move": "petronella", "note": "with next neighbors" }, { "parameter_values": [4], "move": "balance the ring" }, { "parameter_values": ["gentlespoons", "neighbors", false, 4], "move": "roll away", "note": "across" }, { "parameter_values": ["partners", "none", 8], "move": "swing" }], "notes": "Written for David Kreiss-Tompkins, who asked for a dance with lots of role swapping opportunities and a roll-away-to-swing transition", "hook": "Multiple role swap opportunities, mad robin prog.", "id": 2106 },
  { "title": "The Long Road Home", "choreographer_name": "Isaac Banner", "start_type": "Sawtooth Becket", "preamble": "Dancers start becket, then slide one **person** to the right, so larks are standing across from larks and there is an first robin out at the top.", "figures": [{ "parameter_values": ["robins start a left diagonal(ish) half hey for three with the first lark - rights in center, lefts on the end", 6], "move": "custom" }, { "parameter_values": ["ones catch right hands across", 0], "move": "custom" }, { "parameter_values": ["ones", false, true, 2], "move": "pull by dancers", "note": "along the right diagonal to face their current neighbor" }, { "parameter_values": ["neighbors", "", false, "half", "right diagonal", false, false, false, false, 8], "move": "hey" }, { "parameter_values": ["neighbors", "balance", 16], "move": "swing" }, { "parameter_values": [true, 270, 8], "move": "circle" }, { "parameter_values": [4], "move": "balance the ring" }, { "parameter_values": ["neighbors", 4], "move": "California twirl", "progression": 1 }, { "parameter_values": [4], "move": "balance the ring" }, { "parameter_values": ["twos", "shadows", true, 4], "move": "roll away", "note": "" }, { "parameter_values": ["partners", "none", 8], "move": "swing", "note": "- end sawtooth, facing across" }], "notes": "The first lark should end the hey for three in the second robin's spot, the first robin in the lark's spot, and the second robin in the first robin's place - everyone should end **Proper** and across from their partner, ones below. \n\nBe sure to have dancers i.d. their current neighbor after the ones pull by - they *will* be in different couples. After the half hey and swing, dancers should end up directly across from another pair of dancers that includes their shadow. \n\nAfter the California twirl, ones will be facing their partner, but because of the mechanics of the diagonal hey, twos will be facing a *second shadow* (hence the unbalanced roll away in B2).\n\nAs Will Mentor (I believe) says, \"there are end effects - enjoy them.\" At the top of the set after the A2 swing you should end up with a hands 3 containing one second robin. At the bottom you'll have a couple out with a hands 3 above them following the A2 swing. This hands 3 contains an unpaired first lark.\n\nA more in-depth explanation of where everyone ends up throughout -\nThe hey for three at the top starts with robin 1 and robin 2 passing right. Similar to Are You 'Most Done the hey squares the set as it happens and the dancers should end up proper and in a hands 4 with robin 2 above robin 1. \n\nThe ones then pull by right to face their first corner, as though they were starting contra corners, but instead do a half hey for 4 on the right diagonal, with the two twos trading which end of the diagonal they're on. This hey is with the original lark 2 (we'll call them Bob Isaacs), but the NEXT robin 2 (let's call them Susan Michaels).\n\nThe funky part about the active/inactive diagonal hey is that it splits twos further than it splits the ones, so the lark ends up swinging their next neighbor (Susan) close-to-across from where the lark started the dance and the robin ends up swinging their original neighbor (Bob) one couple down from their partner (the swing ends with squared sets, improper). The twos, however, end two minor sets away from each other. \n\nThe B1 reunites the active couple after the California twirl, but the twos are still one minor set distant, so they're facing a shadow (this is Bob and Susan, Bob below). The roll away resyncs partners, but then the swing offsets the twos from the squared set, since the roll-away would, normally, progress dancers along to a new minor set. \n\nFollowing the swing, the hey for 3 starts again with the first robin passing Susan (whom the first lark just swung), while the first robin identifies her new neighbor (let's call them Will Mentor) straight(ish) across from their partner. ", "hook": "Sawtooth hey-for-3 to active/inactive diagonal hey", "id": 848 },
  { "title": "The Salmon Time Around", "choreographer_name": "Isaac Banner", "start_type": "Becket ccw", "preamble": "", "figures": [{ "parameter_values": [true, "across", false, "ladles", false, "neighbors", 4], "move": "form an ocean wave", "note": "" }, { "parameter_values": ["partners", true, 180, 2], "move": "allemande" }, { "parameter_values": ["gentlespoons", false, 180, 2], "move": "allemande" }, { "parameter_values": ["neighbors", "ladles", true, "half", "across", false, false, false, false, 8], "move": "hey", "note": "- neighbor pass right" }, { "parameter_values": ["neighbors", "balance", 16], "move": "swing" }, { "parameter_values": ["ladles", true, 270, 4], "move": "allemande", "progression": 1 }, { "parameter_values": ["ladles", false, 270, 4], "move": "allemande", "note": "(next robins) - larks slide to follow partner" }, { "parameter_values": ["partners", "ladles", true, "half", "across", false, false, false, false, 8], "move": "hey", "note": "- partner pass right" }, { "parameter_values": ["partners", "balance", 16], "move": "swing" }], "notes": "No balance before the swing through in A1", "hook": "Swing through, echoed with a fish ladder", "id": 332 },
  { "title": "The Set Monster", "choreographer_name": "Isaac Banner", "start_type": "Becket", "preamble": "", "figures": [{ "parameter_values": [true, 8], "move": "petronella" }, { "parameter_values": ["neighbors", "none", 8], "move": "swing" }, { "parameter_values": ["ladles", true, "across", 8], "move": "chain" }, { "parameter_values": ["ladles", true, true, 6], "move": "pull by dancers", "note": "to 2nd neighbors", "progression": 1 }, { "parameter_values": ["next neighbors", false, false, 2], "move": "pull by dancers", "progression": 1 }, { "parameter_values": ["3rd neighbors", "partners", true, true, 180, 8], "move": "square through", "note": "and face out" }, { "parameter_values": [false, 4], "move": "long lines", "note": "(facing out)" }, { "parameter_values": ["4th neighbors star through", 4], "move": "custom", "progression": 1 }, { "parameter_values": [true, 8], "move": "petronella" }, { "parameter_values": ["partners", "none", 8], "move": "swing" }], "notes": "", "hook": "", "id": 2068 },
  { "title": "The Sturgeon General", "choreographer_name": "Isaac Banner", "start_type": "improper", "preamble": "", "figures": [{ "parameter_values": ["neighbors", "balance", 16], "move": "swing" }, { "parameter_values": [4], "move": "balance the ring", "note": "" }, { "parameter_values": [true, "across", false, "ladles", false, "neighbors", 4], "move": "form an ocean wave" }, { "parameter_values": ["everyone", true, false, 8], "move": "Rory O'More", "note": "and larks keep sliding past each other" }, { "parameter_values": ["larks catch left hands", 0], "move": "custom" }, { "parameter_values": ["gentlespoons", false, 360, 8], "move": "allemande" }, { "parameter_values": ["partners", "none", 8], "move": "swing" }, { "parameter_values": [true, 270, 8], "move": "circle", "note": "and pass through", "progression": 1 }, { "parameter_values": ["next neighbors", true, 360, 8], "move": "do si do" }], "notes": "", "hook": "Pass the ocean, larks Rory O'More leap ", "id": 464 },
  { "title": "The Sun Never Sets on Puget Sound (Except When It Does, Sometimes)", "choreographer_name": "Isaac Banner", "start_type": "Becket", "preamble": "", "figures": [{ "parameter_values": ["gentlespoons", "", false, "half", "across", false, false, false, false, 8], "move": "hey", "note": "to long waves, robins face out (right hand to P)" }, { "parameter_values": ["gentlespoons", true, true, 8], "move": "box circulate", "note": ", neighbor pivot 1/4 to short waves" }, { "parameter_values": ["everyone", 8], "move": "balance", "note": "short waves forward/back, pass through", "progression": 1 }, { "parameter_values": ["next neighbors", "gentlespoons", true, "half", "across", false, false, false, false, 8], "move": "hey" }, { "parameter_values": ["neighbors", "balance", 16], "move": "swing" }, { "parameter_values": ["gentlespoons", false, 540, 8], "move": "allemande" }, { "parameter_values": ["partners", "none", 8], "move": "swing" }], "notes": "A2 larks pass neighbor right shoulder to enter the hey first", "hook": "Hey to box circ/pivot to hey progression", "id": 1845 },
  { "title": "The Weekend Warrior", "choreographer_name": "Isaac Banner", "start_type": "improper", "preamble": "", "figures": [{ "parameter_values": ["neighbors", "balance", 16], "move": "swing" }, { "parameter_values": [true, 270, 8], "move": "circle" }, { "parameter_values": ["partners", "none", 8], "move": "swing" }, { "parameter_values": ["ladles", true, "across", 8], "move": "chain", "note": "to neighbors" }, { "parameter_values": ["ladles", "", true, "gentlespoons%%1", "across", false, false, false, false, 6], "move": "hey" }, { "parameter_values": ["gentlespoons", true, 90, 2], "move": "allemande", "note": "to short waves, left hand to neighbors" }, { "parameter_values": ["balance & trade the wave - partners passing right, robins taking left hands in the center and neighbors taking right hands on the other side of the set", 8], "move": "custom" }, { "parameter_values": ["everyone", 4], "move": "balance", "note": "short waves forward/back" }, { "parameter_values": ["along", true, 4], "move": "pass through", "note": "to new neighbors", "progression": 1 }], "notes": "", "hook": "Broken half hey to trade the wave", "id": 1971 },
  { "title": "The Wolfe and the Spero", "choreographer_name": "Isaac Banner", "start_type": "improper", "preamble": "Starts with robins back-to-back in the center, facing their neighbors", "figures": [{ "parameter_values": ["neighbors", "gentlespoons", true, "half", "across", false, false, false, false, 8], "move": "hey" }, { "parameter_values": ["neighbors", "none", 8], "move": "swing" }, { "parameter_values": ["gentlespoons", "", false, "half", "across", false, false, false, false, 8], "move": "hey" }, { "parameter_values": ["gentlespoons", 360, 8], "move": "mad robin", "note": "(cw)" }, { "parameter_values": ["gentlespoons", false, 270, 4], "move": "allemande" }, { "parameter_values": ["gentlespoons", true, 270, 4], "move": "allemande", "note": "with new larks", "progression": 1 }, { "parameter_values": ["partners", "meltdown", 8], "move": "swing" }, { "parameter_values": [4], "move": "balance the ring" }, { "parameter_values": [true, "across", true, "ladles", false, "neighbors", 8], "move": "form an ocean wave" }, { "parameter_values": ["ladles", false, 180, 4], "move": "allemande" }], "notes": "Between the extra time from the mad robin and the rapid-fire nature of the allemandes, there should be more than eight counts for the partner swing, but it's still a short  shoulder round.\n\nDuring the first walk-through, have the dancers do a robins allemande left once around to get into position.", "hook": "traveling eye contact during Mary Cay progression", "id": 1755 },
  { "title": "Three Klicks North", "choreographer_name": "Isaac Banner", "start_type": "Becket", "preamble": "Written for a dancer who lived too far away.", "figures": [{ "parameter_values": ["across", 8], "move": "right left through" }, { "parameter_values": [true, 270, 6], "move": "circle" }, { "parameter_values": ["partners", 2], "move": "California twirl", "progression": 1 }, { "parameter_values": [true, 180, 8], "move": "circle" }, { "parameter_values": ["neighbors", "none", 8], "move": "swing" }, { "parameter_values": [true, 8], "move": "long lines" }, { "parameter_values": ["gentlespoons", 360, 8], "move": "mad robin" }, { "parameter_values": ["gentlespoons", false, 2], "move": "pass by" }, { "parameter_values": ["partners", "meltdown", 14], "move": "swing", "note": "" }], "notes": "", "hook": "Mad robin dance with a dreamy opening sequence.", "id": 330 },
  { "title": "Trip to Joy ", "choreographer_name": "Isaac Banner", "start_type": "improper", "preamble": "", "figures": [{ "parameter_values": ["neighbors", true, 180, 4], "move": "gyre" }, { "parameter_values": ["larks draw neighbors across the set", 4], "move": "custom" }, { "parameter_values": ["neighbors", "none", 8], "move": "swing" }, { "parameter_values": ["gentlespoons", true, false, true, 8], "move": "form a long wave" }, { "parameter_values": ["ladles", true, true, true, 8], "move": "form a long wave" }, { "parameter_values": ["partners", true, 270, 4], "move": "gyre" }, { "parameter_values": ["robins draw partners across the set", 4], "move": "custom" }, { "parameter_values": ["partners", "none", 8], "move": "swing" }, { "parameter_values": ["across", 8], "move": "right left through" }, { "parameter_values": [false, 270, "", 6], "move": "star" }, { "parameter_values": ["neighbors", false, false, 2], "move": "pull by dancers", "progression": 1 }], "notes": "", "hook": "Heart of Joy / Trip to ____ mish-mosh", "id": 2113 },
  { "title": "Trip to Mountain City", "choreographer_name": "Isaac Banner", "start_type": "Becket", "preamble": "", "figures": [{ "parameter_values": [true, "couple", "none", 4], "move": "slice", "progression": 1 }, { "parameter_values": ["ladles", "neighbors", false, 4], "move": "give & take" }, { "parameter_values": ["neighbors", "none", 8], "move": "swing" }, { "parameter_values": [true, 8], "move": "long lines", "progression": 1 }, { "parameter_values": [false, 270, "", 8], "move": "star", "note": "with new neighbors" }, { "parameter_values": ["partners", "across", false, 8], "move": "promenade" }, { "parameter_values": ["ladles", "", true, "half", "across", false, false, false, false, 8], "move": "hey" }, { "parameter_values": ["partners", "balance", 16], "move": "swing" }], "notes": "Be sure to ID new neighbors during the long lines.\n\nNeeds a fast tune, otherwise people reach the B2 with 4 beats to spare. Either ask the band to play something at 120 or tell the dancers to enjoy a nice, slow star.", "hook": "Three-quarter star to partner half promenade", "id": 686 },
  { "title": "Trip to Richmond Centre Mall", "choreographer_name": "Isaac Banner", "start_type": "improper", "preamble": "", "figures": [{ "parameter_values": ["ladles", true, false, true, 8], "move": "form a long wave" }, { "parameter_values": ["ladles", false, 270, 4], "move": "allemande" }, { "parameter_values": [false, "across", true, "ladles", false, "neighbors", 4], "move": "form an ocean wave" }, { "parameter_values": ["along", true, 2], "move": "pass through", "note": "to new neighbors", "progression": 1 }, { "parameter_values": ["neighbors", "none", 14], "move": "swing" }, { "parameter_values": ["gentlespoons", false, 540, 8], "move": "allemande" }, { "parameter_values": ["partners", "none", 8], "move": "swing" }, { "parameter_values": ["ladles", true, "across", 8], "move": "chain" }, { "parameter_values": ["ladles", "", true, "half", "across", false, false, false, false, 8], "move": "hey" }], "notes": "First time through the A2 progression will be to your current neighbors from your hands four, since the A1 action is technically with the previous neighbors.", "hook": "", "id": 1979 },
  { "title": "Turn the Tide", "choreographer_name": "Isaac Banner", "start_type": "improper", "preamble": "", "figures": [{ "parameter_values": ["neighbors", true, 540, 8], "move": "gyre", "note": ", robins face in" }, { "parameter_values": [4], "move": "balance the ring" }, { "parameter_values": ["pass the ocean, robins catch left hands", 2], "move": "custom" }, { "parameter_values": ["ladles", false, 180, 2], "move": "allemande" }, { "parameter_values": ["partners", "meltdown", 16], "move": "swing" }, { "parameter_values": [true, 270, 8], "move": "circle" }, { "parameter_values": ["neighbors", "none", 8], "move": "swing" }, { "parameter_values": [4], "move": "balance the ring" }, { "parameter_values": [true, "across", true, "ladles", false, "neighbors", 8], "move": "form an ocean wave" }, { "parameter_values": ["along", true, 4], "move": "pass through" }], "notes": "A1 pass the ocean doesn't end in short waves, but having dancers form a short wave the first time through the lesson as a \"teaching wave\" can help them understand the figure.", "hook": "Double pass the ocean with a hook to your partner", "id": 1493 },
  { "title": "Two Hearts in Time", "choreographer_name": "Isaac Banner", "start_type": "improper", "preamble": "", "figures": [{ "parameter_values": [true, 8], "move": "petronella" }, { "parameter_values": [true, 8], "move": "petronella" }, { "parameter_values": ["neighbors", "balance", 16], "move": "swing" }, { "parameter_values": ["ladles", true, 540, 8], "move": "allemande" }, { "parameter_values": ["partners", "none", 8], "move": "swing" }, { "parameter_values": ["gentlespoons", 360, 6], "move": "mad robin" }, { "parameter_values": [true, 270, 6], "move": "circle" }, { "parameter_values": ["partners", 4], "move": "California twirl", "progression": 1 }], "notes": "Built on top of Don Flaherty's Heartbeat Contra", "hook": "Petronellas with a smoother B and flowy transition", "id": 2014 },
  { "title": "Two Waves, Two Ways", "choreographer_name": "Isaac Banner", "start_type": "Becket", "preamble": "Double Progression", "figures": [{ "parameter_values": [4], "move": "balance the ring" }, { "parameter_values": [true, "across", false, "ladles", false, "partners", 4], "move": "form an ocean wave" }, { "parameter_values": ["everyone", 4], "move": "balance", "note": "short waves" }, { "parameter_values": ["swing through - partner allemande right ½, larks allemande left ½", 4], "move": "custom" }, { "parameter_values": ["neighbors", "balance", 16], "move": "swing" }, { "parameter_values": [true, 8], "move": "long lines" }, { "parameter_values": ["gentlespoons", "", true, "half", "across", false, false, false, false, 8], "move": "hey", "note": "(new larks) to long waves, larks face in", "progression": 1 }, { "parameter_values": ["gentlespoons", true, true, 8], "move": "box circulate", "progression": 1 }, { "parameter_values": ["partners", "none", 8], "move": "swing" }], "notes": "The first progression here happens in the hey. When dancers take hands in long waves to box circulate, the second progression has already happened. It could be helpful to identify neighbors 1, 2, and 3 during the lesson so dancers have faces they can anchor to as they progress.\n\nYou do not interact with neighbor #2 at all outside of the hey and long waves. Before circulating, ID neighbor #3 in your right hand during the long waves balance - this is the neighbor #1 you swing in the next A2. ", "hook": "Short and long waves, swing through and box circ.", "id": 388 },
  { "title": "Umbra and Penumbra", "choreographer_name": "Isaac Banner", "start_type": "improper", "preamble": "", "figures": [{ "parameter_values": ["Robins ricochet in the center while the larks slide left to take their place", 4], "move": "custom" }, { "parameter_values": ["neighbors", "none", 12], "move": "swing" }, { "parameter_values": [true, 270, 6], "move": "circle" }, { "parameter_values": ["partners", true, "", 6], "move": "zig zag" }, { "parameter_values": ["shadows", false, 360, 4], "move": "allemande" }, { "parameter_values": ["partners", "meltdown", 16], "move": "swing" }, { "parameter_values": ["ladles", true, "across", 8], "move": "chain" }, { "parameter_values": [false, 360, "", 8], "move": "star", "progression": 1 }], "notes": "", "hook": "", "id": 1880 },
  { "title": "Van Is My Middle Name", "choreographer_name": "Isaac Banner", "start_type": "improper", "preamble": "Dancers face down the hall in lines of 4, 1s splitting the 2s", "figures": [{ "parameter_values": ["everyone", "all", "forward", "turn-couple", 8], "move": "down the hall" }, { "parameter_values": ["everyone", "all", "forward", "circle", 8], "move": "up the hall" }, { "parameter_values": ["across", true, 4], "move": "pass through" }, { "parameter_values": ["neighbors", "none", 12], "move": "swing" }, { "parameter_values": ["gentlespoons", "", false, "half", "across", false, true, false, false, 8], "move": "hey", "note": "to partners" }, { "parameter_values": ["partners", "none", 8], "move": "swing" }, { "parameter_values": [true, 8], "move": "petronella" }, { "parameter_values": [4], "move": "balance the ring" }, { "parameter_values": ["along", true, 4], "move": "pass through", "note": ", 2s shooting the 1s down the center", "progression": 1 }], "notes": "", "hook": "", "id": 1819 },
  { "title": "Wading in Warm Waters", "choreographer_name": "Isaac Banner", "start_type": "Becket", "preamble": "", "figures": [{ "parameter_values": ["gentlespoons", 360, 8], "move": "mad robin" }, { "parameter_values": [true, 270, 8], "move": "circle" }, { "parameter_values": ["neighbors", "meltdown", 16], "move": "swing" }, { "parameter_values": [false, 360, "hands across", 8], "move": "star", "progression": 1 }, { "parameter_values": ["ladles", 360, 8], "move": "mad robin", "note": "with new neighbors" }, { "parameter_values": ["ladles", false, 2], "move": "pass by", "note": "across" }, { "parameter_values": ["partners", "meltdown", 14], "move": "swing" }], "notes": "", "hook": "", "id": 2010 },
  { "title": "Wave 'em Through", "choreographer_name": "Isaac Banner", "start_type": "improper", "preamble": "Starts in short waves - larks by right in the center, neighbors by left on the sides", "figures": [{ "parameter_values": [false, "across", true, "gentlespoons", true, "neighbors", 4], "move": "form an ocean wave" }, { "parameter_values": ["trade the wave - step forward and partners pass by right shoulders", 4], "move": "custom" }, { "parameter_values": ["neighbors", "none", 8], "move": "swing" }, { "parameter_values": ["gentlespoons", false, 540, 8], "move": "allemande" }, { "parameter_values": ["partners", "none", 8], "move": "swing" }, { "parameter_values": ["ladles", true, "across", 8], "move": "chain", "note": "to neighbors" }, { "parameter_values": [true, "across", true, "ladles", false, "neighbors", 8], "move": "form an ocean wave" }, { "parameter_values": ["ladles", false, 90, 2], "move": "allemande" }, { "parameter_values": ["across", 6], "move": "right left through", "note": "- partners pull by right across" }, { "parameter_values": [false, 360, "", 8], "move": "star", "note": "to short wave w/ next neighbors", "progression": 1 }], "notes": "", "hook": "Pass the ocean to right/left through", "id": 2066 },
  { "title": "Winter Fog", "choreographer_name": "Isaac Banner", "start_type": "Becket", "preamble": "", "figures": [{ "parameter_values": ["ladles", true, "across", 8], "move": "chain" }, { "parameter_values": ["ladles", "", true, "half", "across", false, false, false, false, 8], "move": "hey" }, { "parameter_values": ["neighbors", "balance", 16], "move": "swing" }, { "parameter_values": ["gentlespoons", "", false, "half", "across", false, false, false, false, 8], "move": "hey" }, { "parameter_values": ["gentlespoons", 360, 8], "move": "mad robin" }, { "parameter_values": [true, 270, 6], "move": "circle" }, { "parameter_values": ["partners", "none", 10], "move": "swing" }, { "parameter_values": [true, 0], "move": "slide along set", "progression": 1 }], "notes": "", "hook": "", "id": 415 },
  { "title": "Yenta's Reel", "choreographer_name": "Isaac Banner", "start_type": "Becket", "preamble": "", "figures": [{ "parameter_values": [true, 8], "move": "long lines" }, { "parameter_values": ["partners", "across", false, 8], "move": "promenade", "note": "and hook/loop to new neighbors", "progression": 1 }, { "parameter_values": [false, 270, 8], "move": "circle", "note": "(of course right!)" }, { "parameter_values": [false, "across", true, "gentlespoons", true, "neighbors", 4], "move": "form an ocean wave", "note": "" }, { "parameter_values": ["along", true, 4], "move": "pass through", "note": "walking forward and **left**", "progression": 1 }, { "parameter_values": [false, "across", true, "ladles", false, "neighbors", 4], "move": "form an ocean wave" }, { "parameter_values": ["along", true, 2], "move": "pass through", "note": "walking forward and **right**", "progression": 1 }, { "parameter_values": ["gentlespoons", true, 180, 2], "move": "allemande" }, { "parameter_values": ["partners", "", false, "half", "across", false, false, false, false, 8], "move": "hey" }, { "parameter_values": ["partners", "balance", 16], "move": "swing" }], "notes": "Dancers should use the oomph from the j-hook promenade to drive them into the circle right.", "hook": "Triple prog. Eleanor wave-to-wave to half hey", "id": 860 },
  { "title": "ƐƐƐƐƐ", "choreographer_name": "Isaac Banner", "start_type": "Becket", "preamble": "", "figures": [{ "parameter_values": [true, 8], "move": "long lines" }, { "parameter_values": ["ladles", true, "left diagonal", 8], "move": "chain" }, { "parameter_values": ["ladles", true, "across", 8], "move": "chain", "note": "to -shadows" }, { "parameter_values": [false, 360, "", 8], "move": "star" }, { "parameter_values": ["partners", true, true, 6], "move": "pull by dancers" }, { "parameter_values": ["shadows", false, false, 2], "move": "pull by dancers" }, { "parameter_values": ["2nd shadows", true, true, 8], "move": "box the gnat" }, { "parameter_values": ["2nd shadows", false, true, 2], "move": "pull by dancers" }, { "parameter_values": ["shadows", false, true, 2], "move": "pull by dancers" }, { "parameter_values": ["partners", "none", 12], "move": "swing" }], "notes": "This dance has three shadows, one behind your partner (in the chain) and two beyond your partner (in the right + left grand). Rather than try to identify them all before walking the dance, make a point of calling them out the first time they're encountered in the walkthrough.", "hook": "33333-ish reunion-style becket", "id": 1871 },
];